IF OBJECT_ID('[DashboardPackages_Largest]') IS NOT NULL DROP VIEW [DashboardPackages_Largest]
GO

CREATE VIEW [DashboardPackages_Largest]
AS
SELECT * FROM
(SELECT TOP 10 NP.[Feed_Id],
			   [Package_Name] = NP.[Package_Id],
               P.[Total_Size]
  FROM (SELECT NPV.[NuGetPackageV2_Id],
               [Total_Size] = SUM(NPV.[Package_Size])
          FROM [NuGetPackageVersionsV2] NPV
		  WITH (READUNCOMMITTED)
		 GROUP BY NPV.[NuGetPackageV2_Id]
  ) P
  INNER JOIN [NuGetPackagesV2] NP
        WITH (READUNCOMMITTED)
          ON NP.[NuGetPackageV2_Id] = P.[NuGetPackageV2_Id]
 ORDER BY P.[Total_Size] DESC) _A

UNION ALL

SELECT * FROM
(SELECT TOP 10 *
  FROM (SELECT NP.[Feed_Id],
               [Package_Name] = NP.[Package_Id],
	           [Total_Size] = SUM(NP.[Package_Size])
          FROM [NuGetPackages] NP
		  WITH (READUNCOMMITTED)
         GROUP BY [Feed_Id], [Package_Id]) P
 ORDER BY P.[Total_Size] DESC) _A

UNION ALL

SELECT * FROM
(SELECT TOP 10 NP.[Feed_Id],
              [Package_Name] = CASE WHEN NP.[Scope_Name] = '' THEN NP.[Package_Name] ELSE '@' + NP.[Scope_Name] + '/' + NP.[Package_Name] END,
	          [Total_Size] = (SELECT SUM(NPV.[Package_Size])
	                           FROM [NpmPackageVersions] NPV
						       WITH (READUNCOMMITTED)
						      WHERE NPV.[Package_Id] = NP.[Package_Id])
  FROM [NpmPackages] NP
  WITH (READUNCOMMITTED)
 ORDER BY [Total_Size] DESC) _B

UNION ALL

SELECT * FROM
(SELECT TOP 10 MA.[Feed_Id],
              [Package_Name] = MA.[GroupId_Text] + ':' + MA.[ArtifactId_Text],
			  [Total_Size] = (SELECT SUM(MAF.[File_Size])
			                    FROM [MavenArtifactFiles] MAF
							    WITH (READUNCOMMITTED)
							   WHERE MAF.[MavenArtifact_Id] = MA.[MavenArtifact_Id])
  FROM [MavenArtifacts] MA
  WITH (READUNCOMMITTED)
 ORDER BY [Total_Size] DESC) _C

UNION ALL

SELECT * FROM
(SELECT TOP 10 PGP.[Feed_Id],
              [Package_Name] = COALESCE(NULLIF(PGP.[Group_Name] + ':', ':'), '') + PGP.[Package_Name],
			  [Total_Size] = (SELECT SUM(PGPV.[Package_Size])
			                    FROM [ProGetPackageVersions] PGPV
							    WITH (READUNCOMMITTED)
							   WHERE PGPV.[ProGetPackage_Id] = PGP.[ProGetPackage_Id])
  FROM [ProGetPackages] PGP
  WITH (READUNCOMMITTED)
 ORDER BY [Total_Size] DESC) _D

UNION ALL

SELECT * FROM
(SELECT TOP 10 RG.[Feed_Id],
              [Package_Name] = RG.[Gem_Name],
			  [Total_Size] = (SELECT SUM(RGV.[Gem_Size])
			                    FROM [RubyGemVersions] RGV
							    WITH (READUNCOMMITTED)
							   WHERE RGV.[Gem_Id] = Rg.[Gem_Id])
  FROM [RubyGems] RG
  WITH (READUNCOMMITTED)
 ORDER BY [Total_Size] DESC) _E

 UNION ALL

SELECT * FROM
(SELECT TOP 10 *
  FROM (SELECT VP.[Feed_Id],
               [Package_Name] = VP.[Package_Id],
             [Total_Size] = SUM(VP.[Package_Size])
          FROM [VsixPackages] VP
      WITH (READUNCOMMITTED)
         GROUP BY [Feed_Id], [Package_Id]) P
 ORDER BY P.[Total_Size] DESC) _F

 UNION ALL

SELECT * FROM
(SELECT TOP 10 *
  FROM (SELECT DP.[Feed_Id],
               [Package_Name] = DP.[Package_Name],
             [Total_Size] = SUM(DP.[Package_Size])
          FROM [DebianPackages] DP
      WITH (READUNCOMMITTED)
         GROUP BY [Feed_Id], [Package_Name]) P
 ORDER BY P.[Total_Size] DESC) _G

  UNION ALL

SELECT * FROM
(SELECT TOP 10 *
  FROM (SELECT PP.[Feed_Id],
               [Package_Name] = PP.[Package_Name],
             [Total_Size] = SUM(PP.[Package_Size])
          FROM [PypiPackages] PP
      WITH (READUNCOMMITTED)
         GROUP BY [Feed_Id], [Package_Name]) P
 ORDER BY P.[Total_Size] DESC) _H

 UNION ALL

SELECT * FROM
(SELECT TOP 10 *
  FROM (SELECT HC.[Feed_Id],
               [Package_Name] = HC.[Chart_Name],
               [Total_Size] = SUM(HC.[Chart_Size])
          FROM [HelmCharts] HC
      WITH (READUNCOMMITTED)
         GROUP BY [Feed_Id], [Chart_Name]) P
 ORDER BY P.[Total_Size] DESC) _F

GO