EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'FeedRetentionRules_CreateOrUpdateRule',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Sequence_Number',
    /* Description_Text        */ 'Creates a new feed retention rule or updates an existing one.'
GO

IF OBJECT_ID('[FeedRetentionRules_CreateOrUpdateRule]') IS NOT NULL DROP PROCEDURE [FeedRetentionRules_CreateOrUpdateRule]
GO


SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [FeedRetentionRules_CreateOrUpdateRule]
(
	@Feed_Id INT,
	@DeletePrereleaseVersions_Indicator YNINDICATOR,
	@DeleteCached_Indicator YNINDICATOR,
	@KeepVersions_Count INT,
	@KeepUsedWithin_Days INT,
	@DeletePackageIds_Csv NVARCHAR(MAX),
	@KeepPackageIds_Csv NVARCHAR(MAX),
	@DeleteVersions_Csv NVARCHAR(MAX),
	@KeepVersions_Csv NVARCHAR(MAX),
	@SizeTrigger_KBytes BIGINT,
	@SizeExclusive_Indicator YNINDICATOR,
	@TriggerDownload_Count INT,
	@Sequence_Number INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @Sequence_Number IS NULL
	BEGIN

		SET @Sequence_Number = COALESCE((SELECT MAX([Sequence_Number])
		                                   FROM [FeedRetentionRules]
		                                   WITH (UPDLOCK)
		                                  WHERE [Feed_Id] = @Feed_Id), 0) + 1

		INSERT INTO [FeedRetentionRules]
		(
			[Feed_Id],
			[Sequence_Number],
			[DeletePrereleaseVersions_Indicator],
			[DeleteCached_Indicator],
			[KeepVersions_Count],
			[DeletePackageIds_Csv],
			[KeepPackageIds_Csv],
			[DeleteVersions_Csv],
			[KeepVersions_Csv],
			[KeepUsedWithin_Days],
			[SizeTrigger_KBytes],
			[SizeExclusive_Indicator],
			[TriggerDownload_Count]
		)
		VALUES
		(
			@Feed_Id,
			@Sequence_Number,
			@DeletePrereleaseVersions_Indicator,
			@DeleteCached_Indicator,
			@KeepVersions_Count,
			NULLIF(@DeletePackageIds_Csv, ''),
			NULLIF(@KeepPackageIds_Csv, ''),
			NULLIF(@DeleteVersions_Csv, ''),
			NULLIF(@KeepVersions_Csv, ''),
			@KeepUsedWithin_Days,
			@SizeTrigger_KBytes,
			@SizeExclusive_Indicator,
			@TriggerDownload_Count
		)

	END
	ELSE
	BEGIN

		UPDATE [FeedRetentionRules]
		   SET [DeletePrereleaseVersions_Indicator] = @DeletePrereleaseVersions_Indicator,
		       [DeleteCached_Indicator] = @DeleteCached_Indicator,
		       [KeepVersions_Count] = @KeepVersions_Count,
		       [DeletePackageIds_Csv] = NULLIF(@DeletePackageIds_Csv, ''),
		       [KeepPackageIds_Csv] = NULLIF(@KeepPackageIds_Csv, ''),
		       [DeleteVersions_Csv] = NULLIF(@DeleteVersions_Csv, ''),
		       [KeepVersions_Csv] = NULLIF(@KeepVersions_Csv, ''),
		       [KeepUsedWithin_Days] = @KeepUsedWithin_Days,
		       [SizeTrigger_KBytes] = @SizeTrigger_KBytes,
		       [SizeExclusive_Indicator] = @SizeExclusive_Indicator,
		       [TriggerDownload_Count] = @TriggerDownload_Count
		 WHERE [Feed_Id] = @Feed_Id
		   AND [Sequence_Number] = @Sequence_Number

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO



GRANT EXECUTE ON [FeedRetentionRules_CreateOrUpdateRule] TO [ProGetUser_Role]
GO
	   

