EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'NpmConnectors_CreateOrUpdatePackage',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates or updates connector package metadata for an npm feed.'
GO

IF OBJECT_ID('[NpmConnectors_CreateOrUpdatePackage]') IS NOT NULL DROP PROCEDURE [NpmConnectors_CreateOrUpdatePackage]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [NpmConnectors_CreateOrUpdatePackage]
(
	@Connector_Id INT,
	@Package_Name VARCHAR(200),
	@Package_Version VARCHAR(200),
	@Modified_Date DATETIME,
	@PackageJson_Bytes VARBINARY(MAX)
)
AS BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT * FROM [NpmConnectorPackages] WITH (UPDLOCK) WHERE [Connector_Id] = @Connector_Id AND [Package_Name] = @Package_Name)
	BEGIN

		UPDATE [NpmConnectorPackages]
		   SET [Package_Version] = @Package_Version,
		       [Modified_Date] = @Modified_Date,
			   [PackageJson_Bytes] = @PackageJson_Bytes
		 WHERE [Connector_Id] = @Connector_Id
		   AND [Package_Name] = @Package_Name

	END
	ELSE
	BEGIN

		INSERT INTO [NpmConnectorPackages]
		(
			[Connector_Id],
			[Package_Name],
			[Package_Version],
			[Modified_Date],
			[PackageJson_Bytes]
		)
		VALUES
		(
			@Connector_Id,
			@Package_Name,
			@Package_Version,
			@Modified_Date,
			@PackageJson_Bytes
		)

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [NpmConnectors_CreateOrUpdatePackage] TO [ProGetUser_Role]
GO
