EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Packages_GetPackagePromotions',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'PackagePromotions_Extended',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets a list of package promotions for the specified package or package version.'
GO

IF OBJECT_ID('[Packages_GetPackagePromotions]') IS NOT NULL DROP PROCEDURE [Packages_GetPackagePromotions]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Packages_GetPackagePromotions]
(
    @Package_Name NVARCHAR(200) = NULL,
    @Group_Name NVARCHAR(200) = NULL,
    @From_Feed_Name NVARCHAR(50) = NULL,
    @To_Feed_Name NVARCHAR(50) = NULL,
    @Version_Text NVARCHAR(100) = NULL
)
AS
BEGIN

	SET NOCOUNT ON

    DECLARE @From_Feed_Id INT
    DECLARE @To_Feed_Id INT

    SELECT @From_Feed_Id = [Feed_Id] FROM [Feeds] WHERE [Feed_Name] = @From_Feed_Name
    SELECT @To_Feed_Id = [Feed_Id] FROM [Feeds] WHERE [Feed_Name] = @To_Feed_Name

    SELECT * 
      FROM [PackagePromotions_Extended]
     WHERE (@Package_Name IS NULL OR [Package_Name] = @Package_Name)
       AND (@From_Feed_Id IS NULL OR [From_Feed_Id] = @From_Feed_Id)
       AND (@To_Feed_Id IS NULL OR [To_Feed_Id] = @To_Feed_Id)
       AND (@Version_Text IS NULL OR [Version_Text] = @Version_Text)
       AND (@Group_Name IS NULL OR [Group_Name] = @Group_Name OR [Group_Name] IS NULL)

END
GO

GRANT EXECUTE ON [Packages_GetPackagePromotions] TO [ProGetUser_Role]
GO